@@ -6,7 +6,7 @@
 ;;         Naoya Yamashita <conao3@gmail.com>
 ;; Maintainer: Feng Shu <tumashu@163.com>
 ;; URL: https://github.com/tumashu/ivy-posframe
-;; Version: 0.6.1
+;; Version: 0.6.2
 ;; Keywords: abbrev, convenience, matching, ivy
 ;; Package-Requires: ((emacs "26.0") (posframe "1.0.0") (ivy "0.13.0"))
 
@@ -292,7 +292,11 @@ This variable is useful for `ivy-posframe-read-action' .")
 
 (defun ivy-posframe-hidehandler (_)
   "Hidehandler used by ivy-posframe."
-  (not (minibufferp)))
+  (and (not (minibufferp))
+       ;; Note: when run ivy-avy, buffer will be temp changed, make
+       ;; sure do not autohide posframe at this situation.
+       ;; More detail: https://github.com/tumashu/ivy-posframe/issues/114
+       (not (equal (current-buffer) (window-buffer (ivy-posframe--window))))))
 
 (defun ivy-posframe-get-size ()
   "The default functon used by `ivy-posframe-size-function'."
